@@ -1,5 +1,6 @@
 import datetime as dt
 import decimal
+import enum
 import io
 import json
 import math
@@ -1162,6 +1163,20 @@ def test_loads_non_c_contiguous():
         ujson.loads(buffer)
 
 
+@pytest.mark.parametrize(
+    "enum_classes, value, expected",
+    [
+        ((enum.IntEnum,), 42, "42"),
+        ((float, enum.Enum), 3.1416, "3.1416"),
+    ],
+)
+def test_enum(enum_classes, value, expected):
+    class MyEnum(*enum_classes):
+        FOO = value
+
+    assert ujson.dumps(MyEnum.FOO) == expected
+
+
 """
 The following checks are not part of the standard test suite.
 They can be run manually as follows:
